emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

emacs-29 8fb2afe0511: ; Fix typos


From: Stefan Kangas
Subject: emacs-29 8fb2afe0511: ; Fix typos
Date: Thu, 8 Dec 2022 01:19:53 -0500 (EST)

branch: emacs-29
commit 8fb2afe051168b2eac2bba0ee102039d0af90a05
Author: Stefan Kangas <stefankangas@gmail.com>
Commit: Stefan Kangas <stefankangas@gmail.com>

    ; Fix typos
---
 ChangeLog.3                                   | 6 +++---
 admin/notes/tree-sitter/build-module/build.sh | 2 +-
 configure.ac                                  | 2 +-
 doc/emacs/macos.texi                          | 2 +-
 lisp/comint.el                                | 2 +-
 lisp/external-completion.el                   | 2 +-
 lisp/international/ogonek.el                  | 4 ++--
 lisp/org/ox.el                                | 2 +-
 lisp/progmodes/bat-mode.el                    | 2 +-
 test/lisp/gnus/mml-sec-tests.el               | 2 +-
 10 files changed, 13 insertions(+), 13 deletions(-)

diff --git a/ChangeLog.3 b/ChangeLog.3
index 136a276b632..edb738b56c9 100644
--- a/ChangeLog.3
+++ b/ChangeLog.3
@@ -113661,7 +113661,7 @@
 
 2019-09-04  Lars Ingebrigtsen  <larsi@gnus.org>
 
-       Make the NSM not pop up an X dialogue on non-mouse actions
+       Make the NSM not pop up an X dialog on non-mouse actions
 
        * lisp/emacs-lisp/rmc.el (read-multiple-choice): Don't pop up X
        dialogs on (url-retrieve "https://expired.badssl.com/"; #'ignore)
@@ -124088,7 +124088,7 @@
        This is fine when the GPG key is cached and each entry can be
        decrypted without user interaction.  However, for security some people
        have their GPG on a hardware token like a Yubikey setup so that they
-       have to touch a sensor on the toke for every cryptographic operation,
+       have to touch a sensor on the token for every cryptographic operation,
        in which case it becomes inconvenient as each attempt to find an entry
        requires a variable number of touches of the hardware token.
 
@@ -202762,7 +202762,7 @@
        (w32_frame_parm_handlers): Add entries for new frame
        parameters.
        * src/w32font.c (Fx_select_font): Handle `z-group-above'
-       frames during font selection dialogue.
+       frames during font selection dialog.
        * src/w32term.c (construct_mouse_wheel): Construct mouse wheel
        event from F's w32 window.
        (w32_mouse_position): Handle child frames.
diff --git a/admin/notes/tree-sitter/build-module/build.sh 
b/admin/notes/tree-sitter/build-module/build.sh
index a71ccaa4edb..d562f1a7846 100755
--- a/admin/notes/tree-sitter/build-module/build.sh
+++ b/admin/notes/tree-sitter/build-module/build.sh
@@ -34,7 +34,7 @@ git clone "https://github.com/tree-sitter/${repo}.git"; \
     --depth 1 --quiet
 cp "${grammardir}"/grammar.js "${sourcedir}"
 # We have to go into the source directory to compile, because some
-# C files referes to files like "../../common/scanner.h".
+# C files refer to files like "../../common/scanner.h".
 cd "${sourcedir}"
 
 ### Build
diff --git a/configure.ac b/configure.ac
index b844c6bc730..432638f8721 100644
--- a/configure.ac
+++ b/configure.ac
@@ -5998,7 +5998,7 @@ case $opsys in
   gnu-linux | gnu-kfreebsd )
     AC_DEFINE([USG], [])
     AC_DEFINE([GNU_LINUX], [],
-      [Define if ths system is compatible with GNU/Linux.])
+      [Define if this system is compatible with GNU/Linux.])
     ;;
 
   hpux*)
diff --git a/doc/emacs/macos.texi b/doc/emacs/macos.texi
index 1457a8bc3a3..96f881ca124 100644
--- a/doc/emacs/macos.texi
+++ b/doc/emacs/macos.texi
@@ -154,7 +154,7 @@ titlebar.
 @vindex ns-confirm-quit
 @item ns-confirm-quit
 This variable specifies whether to display a graphical confirmation
-dialogue on quitting.
+dialog on quitting.
 
 @vindex ns-auto-hide-menu-bar
 @item ns-auto-hide-menu-bar
diff --git a/lisp/comint.el b/lisp/comint.el
index 4d9fc501874..f0bb8da4355 100644
--- a/lisp/comint.el
+++ b/lisp/comint.el
@@ -384,7 +384,7 @@ This variable is buffer-local."
    "\\(?:\\(?:, try\\)? *again\\| (empty for no passphrase)\\| (again)\\)?"
    ;; "[[:alpha:]]" used to be "for", which fails to match non-English.
    "\\(?: [[:alpha:]]+ .+\\)?[[:blank:]]*[::៖][[:space:]]*\\'"
-   ;; The ccrypt encryption dialogue doesn't end with a colon, so
+   ;; The ccrypt encryption dialog doesn't end with a colon, so
    ;; treat it specially.
    "\\|^Enter encryption key: (repeat) *\\'"
    ;; openssh-8.6p1 format: "(user@host) Password:".
diff --git a/lisp/external-completion.el b/lisp/external-completion.el
index 4865e1aa262..a661f031c77 100644
--- a/lisp/external-completion.el
+++ b/lisp/external-completion.el
@@ -154,7 +154,7 @@ EXPANDED-PATTERN."
              ;;
              ;; * when `_method' is `nil' or `lambda' which some
              ;;   frontends will invoke.  Here, `all' should be
-             ;;   suficient information for `complete-with-action' to
+             ;;   sufficient information for `complete-with-action' to
              ;;   do the job correctly.
              (complete-with-action action all string pred))))))))
 
diff --git a/lisp/org/ox.el b/lisp/org/ox.el
index 5c0a8f2424b..f6629cde4dc 100644
--- a/lisp/org/ox.el
+++ b/lisp/org/ox.el
@@ -2559,7 +2559,7 @@ variable and do not do anything that might alter it (like 
calling a
 major mode) to prevent data corruption.  Also, do note that Emacs may
 jump into the created buffer if the original file buffer is closed and
 then re-opened.  Making edits in the buffer copy may also trigger
-Emacs save dialogue.  Prefer using `org-export-with-buffer-copy' macro
+Emacs save dialog.  Prefer using `org-export-with-buffer-copy' macro
 when possible.
 
 When optional key `:to-buffer' is non-nil, copy into BUFFER.
diff --git a/lisp/progmodes/bat-mode.el b/lisp/progmodes/bat-mode.el
index 6bac297a298..5e833047af1 100644
--- a/lisp/progmodes/bat-mode.el
+++ b/lisp/progmodes/bat-mode.el
@@ -44,7 +44,7 @@
 ;; Separate package `dos-indent' (Matthew Fidler) provides rudimentary
 ;; indentation, see https://www.emacswiki.org/emacs/dos-indent.el.
 ;;
-;; Acknowledgements:
+;; Acknowledgments:
 ;;
 ;; Inspired by `batch-mode' (Agnar Renolen) and `cmd-mode' (Tadamegu Furukawa).
 
diff --git a/test/lisp/gnus/mml-sec-tests.el b/test/lisp/gnus/mml-sec-tests.el
index e4e607b70e6..f8ebf2f3a99 100644
--- a/test/lisp/gnus/mml-sec-tests.el
+++ b/test/lisp/gnus/mml-sec-tests.el
@@ -789,7 +789,7 @@ With Ma Gnus v0.14 and earlier a signature would be created 
with a wrong key."
 
 ;; TODO Passphrase passing and caching in Emacs does not seem to work
 ;; with gpgsm at all.
-;; Independently of caching settings, a pinentry dialogue is displayed.
+;; Independently of caching settings, a pinentry dialog is displayed.
 ;; Thus, the following tests require the user to enter the correct gpgsm
 ;; passphrases at the correct points in time.  (Either empty string or
 ;; "Passphrase".)



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/lisp/international/ogonek.el b/lisp/international/ogonek.el
index ac9a213ec75..216d2fd0f20 100644
--- a/lisp/international/ogonek.el
+++ b/lisp/international/ogonek.el
@@ -214,7 +214,7 @@ The functions come in the following groups.
  is stored in the constant `ogonek-name-encoding-alist'.
 
  The `ogonek' functions refer to five variables in which the suggested
- answers to dialogue questions are stored.  The variables and their
+ answers to dialog questions are stored.  The variables and their
  default values are:
 
    ogonek-from-encoding           iso8859-2
@@ -266,7 +266,7 @@ The functions come in the following groups.
   (switch-to-buffer " *ogonek-how*")
   (goto-char (point-min)))
 
 ;; ---- Variables keeping the suggested answers to dialogue questions -----
 (defvar ogonek-encoding-choices
   (cons 'choice
        (mapcar (lambda (x) (list 'const (car x)))
@@ -266,7 +266,7 @@ The functions come in the following groups.
   (goto-char (point-min)))
 
-;; ---- Variables keeping the suggested answers to dialogue questions -----
+;; ---- Variables keeping the suggested answers to dialog questions -----
 (defvar ogonek-encoding-choices
   (cons 'choice